diff --git tests/phpunit/tests/feed/atom.php tests/phpunit/tests/feed/atom.php
index fbe064b..8f04a90 100644
--- tests/phpunit/tests/feed/atom.php
+++ tests/phpunit/tests/feed/atom.php
@@ -197,4 +197,39 @@ class Tests_Feeds_Atom extends WP_UnitTestCase {
 			}
 		}
 	}
+
+	/**
+	 * Tests atom_enclosures().
+	 *
+	 * @ticket 41905
+	 */
+	public function test_atom_enclosures() {
+		// Latest post ID.
+		$post_id = end( self::$posts );
+
+		// Add enclosure meta.
+		$meta_enclosures = array(
+			"https://wordpress.dev/wp-content/uploads/2017/09/movie.mp4\n318465\nvideo/mp4",
+			"https://wordpress.dev/wp-content/uploads/2017/01/audio.mp3\n48934\naudio/mpeg",
+		);
+		foreach ( $meta_enclosures as $meta_enclosure ) {
+			add_post_meta( $post_id, 'enclosure', $meta_enclosure, false );
+		}
+
+		// Setup global post object used by atom_enclosure().
+		$GLOBALS['post'] = get_post( $post_id );
+
+		// Actual output.
+		atom_enclosure();
+
+		// Cleanup.
+		unset( $GLOBALS['post'] );
+
+		// Expected output.
+		$expected = join( '', array(
+			'<link href="https://wordpress.dev/wp-content/uploads/2017/09/movie.mp4" rel="enclosure" length="318465" type="video/mp4" />' . "\n",
+			'<link href="https://wordpress.dev/wp-content/uploads/2017/01/audio.mp3" rel="enclosure" length="48934" type="audio/mpeg" />' . "\n",
+		) );
+		$this->expectOutputString( $expected );
+	}
 }
diff --git tests/phpunit/tests/feed/rss2.php tests/phpunit/tests/feed/rss2.php
index f0d7919..8323b29 100644
--- tests/phpunit/tests/feed/rss2.php
+++ tests/phpunit/tests/feed/rss2.php
@@ -454,4 +454,39 @@ class Tests_Feeds_RSS2 extends WP_UnitTestCase {
 		// There should only be one <rss> child element.
 		$this->assertEquals( 1, count( $rss ) );
 	}
+
+	/**
+	 * Tests rss_enclosures().
+	 *
+	 * @ticket 41905
+	 */
+	public function test_rss_enclosures() {
+		// Latest post ID.
+		$post_id = end( self::$posts );
+
+		// Add enclosure meta.
+		$meta_enclosures = array(
+			"https://wordpress.dev/wp-content/uploads/2017/09/movie.mp4\n318465\nvideo/mp4",
+			"https://wordpress.dev/wp-content/uploads/2017/01/audio.mp3\n48934\naudio/mpeg",
+		);
+		foreach ( $meta_enclosures as $meta_enclosure ) {
+			add_post_meta( $post_id, 'enclosure', $meta_enclosure, false );
+		}
+
+		// Setup global post object used by rss_enclosure().
+		$GLOBALS['post'] = get_post( $post_id );
+
+		// Actual output.
+		rss_enclosure();
+
+		// Cleanup.
+		unset( $GLOBALS['post'] );
+
+		// Expected output.
+		$expected = join( '', array(
+			'<enclosure url="https://wordpress.dev/wp-content/uploads/2017/09/movie.mp4" length="318465" type="video/mp4" />' . "\n",
+			'<enclosure url="https://wordpress.dev/wp-content/uploads/2017/01/audio.mp3" length="48934" type="audio/mpeg" />' . "\n",
+		) );
+		$this->expectOutputString( $expected );
+	}
 }

diff --git src/wp-includes/feed.php src/wp-includes/feed.php
index 731b66e..1a48792 100644
--- src/wp-includes/feed.php
+++ src/wp-includes/feed.php
@@ -449,7 +449,7 @@ function html_type_rss() {
  * the user has the password for the post. If not then it will return before
  * displaying.
  *
  * Also uses the function get_post_custom() to get the post's 'enclosure'
  * metadata field and parses the value to display the enclosure(s). The
  * enclosure(s) consist of enclosure HTML tag(s) with a URI and other
  * attributes.
@@ -460,24 +460,24 @@ function rss_enclosure() {
 	if ( post_password_required() )
 		return;
 
-	foreach ( (array) get_post_custom() as $key => $val) {
-		if ($key == 'enclosure') {
-			foreach ( (array) $val as $enc ) {
-				$enclosure = explode("\n", $enc);
-
-				// only get the first element, e.g. audio/mpeg from 'audio/mpeg mpga mp2 mp3'
-				$t = preg_split('/[ \t]/', trim($enclosure[2]) );
-				$type = $t[0];
-
-				/**
-				 * Filters the RSS enclosure HTML link tag for the current post.
-				 *
-				 * @since 2.2.0
-				 *
-				 * @param string $html_link_tag The HTML link tag with a URI and other attributes.
-				 */
-				echo apply_filters( 'rss_enclosure', '<enclosure url="' . trim( htmlspecialchars( $enclosure[0] ) ) . '" length="' . trim( $enclosure[1] ) . '" type="' . $type . '" />' . "\n" );
-			}
+	$meta_enclosures = get_post_meta( get_the_ID(), 'enclosure', false );
+
+	foreach ( (array) $meta_enclosures as $key => $val ) {
+		foreach ( (array) $val as $enc ) {
+			$enclosure = explode( "\n", $enc );
+
+			// Only get the first element, e.g. audio/mpeg from 'audio/mpeg mpga mp2 mp3'.
+			$t    = preg_split( '/[ \t]/', trim( $enclosure[2] ) );
+			$type = $t[0];
+
+			/**
+			 * Filters the RSS enclosure HTML link tag for the current post.
+			 *
+			 * @since 2.2.0
+			 *
+			 * @param string $html_link_tag The HTML link tag with a URI and other attributes.
+			 */
+			echo apply_filters( 'rss_enclosure', '<enclosure url="' . trim( htmlspecialchars( $enclosure[0] ) ) . '" length="' . trim( $enclosure[1] ) . '" type="' . $type . '" />' . "\n" );
 		}
 	}
 }
@@ -489,7 +489,7 @@ function rss_enclosure() {
  * the user has the password for the post. If not then it will return before
  * displaying.
  *
  * Also uses the function get_post_custom() to get the post's 'enclosure'
  * metadata field and parses the value to display the enclosure(s). The
  * enclosure(s) consist of link HTML tag(s) with a URI and other attributes.
  *
@@ -499,19 +499,18 @@ function atom_enclosure() {
 	if ( post_password_required() )
 		return;
 
-	foreach ( (array) get_post_custom() as $key => $val ) {
-		if ($key == 'enclosure') {
-			foreach ( (array) $val as $enc ) {
-				$enclosure = explode("\n", $enc);
-				/**
-				 * Filters the atom enclosure HTML link tag for the current post.
-				 *
-				 * @since 2.2.0
-				 *
-				 * @param string $html_link_tag The HTML link tag with a URI and other attributes.
-				 */
-				echo apply_filters( 'atom_enclosure', '<link href="' . trim( htmlspecialchars( $enclosure[0] ) ) . '" rel="enclosure" length="' . trim( $enclosure[1] ) . '" type="' . trim( $enclosure[2] ) . '" />' . "\n" );
-			}
+	$meta_enclosures = get_post_meta( get_the_ID(), 'enclosure', false );
+	foreach ( (array) $meta_enclosures as $key => $val ) {
+		foreach ( (array) $val as $enc ) {
+			$enclosure = explode( "\n", $enc );
+			/**
+			 * Filters the atom enclosure HTML link tag for the current post.
+			 *
+			 * @since 2.2.0
+			 *
+			 * @param string $html_link_tag The HTML link tag with a URI and other attributes.
+			 */
+			echo apply_filters( 'atom_enclosure', '<link href="' . trim( htmlspecialchars( $enclosure[0] ) ) . '" rel="enclosure" length="' . trim( $enclosure[1] ) . '" type="' . trim( $enclosure[2] ) . '" />' . "\n" );
 		}
 	}
 }
@@ -449,7 +449,7 @@ function html_type_rss() {
  * displaying.
  *
- * Also uses the function get_post_custom() to get the post's 'enclosure'
+ * Also uses the function get_post_meta() to get the post's 'enclosure'
  * metadata field and parses the value to display the enclosure(s). The
  * enclosure(s) consist of enclosure HTML tag(s) with a URI and other
@@ -489,7 +489,7 @@ function rss_enclosure() {
  * displaying.
  *
- * Also uses the function get_post_custom() to get the post's 'enclosure'
+ * Also uses the function get_post_meta() to get the post's 'enclosure'
  * metadata field and parses the value to display the enclosure(s). The
  * enclosure(s) consist of link HTML tag(s) with a URI and other attributes.